@@ -3,6 +3,7 @@ from .typ import useDefaultType
 from typing import Union, List
 from .color import hex_to_rgb, rgb_to_hsl, ColorFormat
 import sys
+import inspect
 
 
 def useDefault(name, default):
@@ -50,6 +51,23 @@ def password(name, default, tip="", hide_if="", style="", cls="") -> str:
     return useDefault(name, default)
 
 
+def tool(name, default, tools, tip="", hide_if="", style="", cls="") -> str:
+    ret = useDefault(name, default)
+    if isinstance(ret, str):
+        # 获取调用栈
+        frame = inspect.currentframe()
+        try:
+            # 获取调用者的全局变量
+            caller_globals = frame.f_back.f_globals
+        finally:
+            del frame
+
+        ret = eval(ret, caller_globals)
+        return ret
+    else:
+        return ret
+
+
 def color(
     name,
     default,
